# ImageCrawler: Echo

## Purpose

just generates the same URIs... again .. and again...

Not an actual crawler.
More like an Parrot that is trained to repeat what you tell it to say.

## Config

### `image_uri`

- the URI to the image to show
- type: string
- example: "https://media.giphy.com/media/qQx7B5z3hG19K/giphy.gif"
